get_date_from_arg

Function get_date_from_arg 

pub fn get_date_from_arg(date_arg: &str, end: bool) -> DateTime<FixedOffset>
Returns a DateTime given a date string If end == true, the date returned has a time of 23:59:59 to support the range being inclusive so that 12-01..12-10 would include all sessions started on 12-10